/***************************************************
 * Time_test.pde
 * 
 * K.Morishita Kumamoto-University, June 2011.
 * timer2の割り込みを利用して、時刻の管理を行うサンプルスケッチです。
 * とりあえずArduinoに書き込んで確認してください。
 * http://morimori2008.web.fc2.com/index.html
 ************************************************/

// ライブラリの読み込み
#include <time_personal.h>
#include <MsTimer2.h>
// 外部変数（オブジェクト）宣言
GPS::Time time(20110101ul);      // 時刻管理クラスの宣言。引数は日付。第2引数にGPS週秒を付けることも可能。
long int rtc = 0l;                // 起動してからの経過時間を格納する

// 時刻のカウントを割り込みを使って行う
void clock(void){
  rtc++;
  return;
}

void setup()
{
  MsTimer2::set(1000, clock);      // 割り込みのタイマーを設定（割り込みを利用したソフトウェア割り込みのように見える処理）
  MsTimer2::start();               // 割り込みのタイマーを開始
  Serial.begin(9600);             // Open serial connection to report values to host
  Serial.println("Starting up");  // 起動メッセージを送る
  delay(800);                      // 適当な待ち
}

/**********************************************
 * 繰り返し処理（loop関数が繰り返し呼び出される）
 * 実際の処理はWhile(1)loop();と同じ
 ***********************************************/
void loop()
{
  int i, air_pressure_I, temp_I, air_pressure_F, temp_F;
  const int ad_buff_size = 241, pressure_buff_size = 5;
  int ad_value, ad_values[ad_buff_size], pressure_value, pressure_values[pressure_buff_size];
  static long int rtc_backup = 0l;
  int freq;  // for RH

  if(rtc_backup != rtc){
    (void)time.Increase_Clock(3600l);   // 時刻更新。引数は時間の増減量[sec]。他にも一日だけ日付を増減させるメソッドもあります。
    rtc_backup = rtc;                   // バックアップ
    // シリアルへ送信
    Serial.print("Date,");
    Serial.print(time.getDate());      // 日付
    Serial.print(",GPS week,");
    Serial.print(time.getGPS_week());  // GPS週番号
    Serial.print(",week,");
    Serial.print(time.getWeek());      // 曜日を数字で返す（日曜日が0）
    Serial.print(",Clock,");
    Serial.print(time.getClock());     // 時刻(hhmmss形式)
    Serial.print(",Time,");            // こちらは正真正銘ただの経過時間
    Serial.print(rtc / 3600l);
    Serial.print(":");
    Serial.print((rtc % 3600l) / 60);
    Serial.print(":");
    Serial.println(rtc % 60l);   
  }
}


